@@ -1,7 +1,8 @@
 
 #' Returns the metrics for a valid ImpactStory ID
 #'
-#' @param id  An ImpactStory ID
+#' @param key An ImpactStory API key
+#' @param id  An object ID
 #' @param nspace Namespace for the identifier. Valid namespaces include doi, github (among others). Read more about available metrics here: \url{http://impactstory.org/faq}
 #' @export
 #' @examples \dontrun{
@@ -13,15 +14,14 @@
 #' metrics('10.6084/m9.figshare.91458')
 #'}
 #' @author Karthik Ram \email{karthik.ram@@gmail.com}
-metrics <- function(id = NULL, nspace = 'doi') {
+metrics <- function(id = NULL, nspace = 'doi', key = getOption("ImpactStoryKey", stop("Missing Dropbox consumer key"))) {
 if(is.null(id))
 	stop("No id specified", call.=FALSE)
 
-id2 <- ISid(id, nspace)	
-metrics <- getURL(paste0("http://api.impactstory.org/item/", id2))
+metrics <- getURL(paste0("http://api.impactstory.org/v1/item/", nspace, "/", id, "?key=", key))
 
  if(length(grep('404 Not Found', metrics))>0 && grep('404 Not Found', metrics)==1) {
-	stop("No metrics found on supplied Impact Story ID. Supplied ID may not be valid", call.= FALSE)
+	stop("Item not found in ImpactStory database.", call.= FALSE)
 }
 
 metric_data <- fromJSON(metrics, depth = 150L)
