@@ -3,6 +3,13 @@ library(RCurl)
 library(RJSONIO)
 library(stringr)
 
+# ------------ building
+setwd('~/Github/ropensci/rImpactStory/')
+document(".")
+check_doc()
+check()
+
+
 
 #' Creates a collection from a list of Impact Story ids (not working)
 #'
@@ -11,7 +18,7 @@ library(stringr)
 #' @export
 #' @return collection id
 #' @examples \dontrun{
-#' doi <- c("10.1145/1327452.1327492", "10.1080/10556781003625177")	
+#' doi <- c("10.1145/1327452.1327492", "10.1080/10556781003625177")
 #' pmid <- c("19782018","17420288", "17593900", "17420288")
 #' create_collection(title = "my collection", list_of_items) # list must be valid Impact Story IDs.
 #'}
@@ -23,12 +30,12 @@ create_collection <- function(title = NULL, objects = NULL) {
 		stop("You need to specify a list of objects to curate into a collection. See ?create_collection for examples.", call.=FALSE)
 
 
- 
-	object_list <- toJSON(objects)	
-	browser()
-	new_id <- postForm('http://api.impactstory.it/collection', args = object_list, style = "POST")  	
 
-} 
+	object_list <- toJSON(objects)
+	browser()
+	new_id <- postForm('http://api.impactstory.it/collection', args = object_list, style = "POST")
+
+}
 
 # Tests
 
@@ -41,7 +48,7 @@ x=list(pmid = pmid, doi =doi)
  	browser()
  	})
 
- 
+
  names(doi) <- rep("doi", length(doi))
  all <- c(pmid, doi)
-object_list <- toJSON(all, .withNames = TRUE)
\ No newline at end of file
+object_list <- toJSON(all, .withNames = TRUE)
